@@ -3,9 +3,9 @@ Main interface for mediatailor service type definitions.
 
 Usage::
 
-    from mypy_boto3.mediatailor.type_defs import CdnConfigurationTypeDef
+    from mypy_boto3.mediatailor.type_defs import AvailSuppressionTypeDef
 
-    data: CdnConfigurationTypeDef = {...}
+    data: AvailSuppressionTypeDef = {...}
 """
 import sys
 from typing import Dict, List
@@ -21,6 +21,7 @@ else:
 
 
 __all__ = (
+    "AvailSuppressionTypeDef",
     "CdnConfigurationTypeDef",
     "DashConfigurationForPutTypeDef",
     "DashConfigurationTypeDef",
@@ -34,6 +35,12 @@ __all__ = (
     "PutPlaybackConfigurationResponseTypeDef",
 )
 
+AvailSuppressionTypeDef = TypedDict(
+    "AvailSuppressionTypeDef",
+    {"Mode": Literal["OFF", "BEHIND_LIVE_EDGE"], "Value": str},
+    total=False,
+)
+
 CdnConfigurationTypeDef = TypedDict(
     "CdnConfigurationTypeDef",
     {"AdSegmentUrlPrefix": str, "ContentSegmentUrlPrefix": str},
@@ -70,6 +77,7 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
     "GetPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
+        "AvailSuppression": AvailSuppressionTypeDef,
         "CdnConfiguration": CdnConfigurationTypeDef,
         "DashConfiguration": DashConfigurationTypeDef,
         "HlsConfiguration": HlsConfigurationTypeDef,
@@ -91,6 +99,7 @@ PlaybackConfigurationTypeDef = TypedDict(
     "PlaybackConfigurationTypeDef",
     {
         "AdDecisionServerUrl": str,
+        "AvailSuppression": AvailSuppressionTypeDef,
         "CdnConfiguration": CdnConfigurationTypeDef,
         "DashConfiguration": DashConfigurationTypeDef,
         "HlsConfiguration": HlsConfigurationTypeDef,
@@ -125,6 +134,7 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
     "PutPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
+        "AvailSuppression": AvailSuppressionTypeDef,
         "CdnConfiguration": CdnConfigurationTypeDef,
         "DashConfiguration": DashConfigurationTypeDef,
         "HlsConfiguration": HlsConfigurationTypeDef,
